Crate tauri_plugin_geolocation

Crate tauri_plugin_geolocation 

Access device geolocation APIs.

Cargo features

Structs

Coordinates
The GPS coordinates of a Position, along with the accuracy of each reading.
Geolocation
Access to the geolocation APIs.
PermissionStatus
The current permission state for the geolocation APIs.
Position
A geolocation reading, as returned by get_current_position and reported through WatchEvent::Position.
PositionOptions
Options used to configure a get_current_position or watch_position request.

Enums

Error
Errors that can occur while interacting with the geolocation APIs.
PermissionType
The individual permission aliases that can be requested with request_permissions.
WatchEvent
A single update sent through the channel callback registered with watch_position.

Traits

GeolocationExt
Extensions to tauri::App, tauri::AppHandle, tauri::WebviewWindow, tauri::Webview and tauri::Window to access the geolocation APIs.

Functions

init
Initializes the plugin.

Type Aliases

Result
Alias for the result type returned by the geolocation APIs.