pub struct Coordinates {
pub latitude: f64,
pub longitude: f64,
pub accuracy: f64,
pub altitude_accuracy: Option<f64>,
pub altitude: Option<f64>,
pub speed: Option<f64>,
pub heading: Option<f64>,
}Expand description
The GPS coordinates of a Position, along with the accuracy of each reading.
Fields
latitude: f64Latitude in decimal degrees.
longitude: f64Longitude in decimal degrees.
accuracy: f64Accuracy level of the latitude and longitude coordinates in meters.
altitude_accuracy: Option<f64>Accuracy level of the altitude coordinate in meters, if available. Available on all iOS versions and on Android 8 and above.
altitude: Option<f64>The altitude the user is at, if available.
speed: Option<f64>The speed the user is traveling, in meters per second, if available.
heading: Option<f64>The heading the user is facing, if available.