Access device geolocation APIs.
Cargo features
- specta: Add support for
specta::spectaon structs likePermissionStatus,PositionOptions.
Structs
- Coordinates
- The GPS coordinates of a
Position, along with the accuracy of each reading. - Geolocation
- Access to the geolocation APIs.
- Permission
Status - The current permission state for the geolocation APIs.
- Position
- A geolocation reading, as returned by
get_current_positionand reported throughWatchEvent::Position. - Position
Options - Options used to configure a
get_current_positionorwatch_positionrequest.
Enums
- Error
- Errors that can occur while interacting with the geolocation APIs.
- Permission
Type - The individual permission aliases that can be requested with
request_permissions. - Watch
Event - A single update sent through the channel callback registered with
watch_position.
Traits
- Geolocation
Ext - Extensions to
tauri::App,tauri::AppHandle,tauri::WebviewWindow,tauri::Webviewandtauri::Windowto access the geolocation APIs.
Functions
- init
- Initializes the plugin.
Type Aliases
- Result
- Alias for the result type returned by the geolocation APIs.